@@ -358,22 +358,22 @@ _thunar_marshal_VOID__UINT64_UINT_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,POINTER,UINT,STRING (thunar-marshal.list:9) */
+/* VOID:UINT,BOXED,UINT,STRING (thunar-marshal.list:9) */
 void
-_thunar_marshal_VOID__UINT_POINTER_UINT_STRING (GClosure     *closure,
-                                                GValue       *return_value G_GNUC_UNUSED,
-                                                guint         n_param_values,
-                                                const GValue *param_values,
-                                                gpointer      invocation_hint G_GNUC_UNUSED,
-                                                gpointer      marshal_data)
+_thunar_marshal_VOID__UINT_BOXED_UINT_STRING (GClosure     *closure,
+                                              GValue       *return_value G_GNUC_UNUSED,
+                                              guint         n_param_values,
+                                              const GValue *param_values,
+                                              gpointer      invocation_hint G_GNUC_UNUSED,
+                                              gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__UINT_POINTER_UINT_STRING) (gpointer     data1,
-                                                               guint        arg_1,
-                                                               gpointer     arg_2,
-                                                               guint        arg_3,
-                                                               gpointer     arg_4,
-                                                               gpointer     data2);
-  register GMarshalFunc_VOID__UINT_POINTER_UINT_STRING callback;
+  typedef void (*GMarshalFunc_VOID__UINT_BOXED_UINT_STRING) (gpointer     data1,
+                                                             guint        arg_1,
+                                                             gpointer     arg_2,
+                                                             guint        arg_3,
+                                                             gpointer     arg_4,
+                                                             gpointer     data2);
+  register GMarshalFunc_VOID__UINT_BOXED_UINT_STRING callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
@@ -389,13 +389,50 @@ _thunar_marshal_VOID__UINT_POINTER_UINT_STRING (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__UINT_POINTER_UINT_STRING) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__UINT_BOXED_UINT_STRING) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
             g_marshal_value_peek_uint (param_values + 1),
-            g_marshal_value_peek_pointer (param_values + 2),
+            g_marshal_value_peek_boxed (param_values + 2),
             g_marshal_value_peek_uint (param_values + 3),
             g_marshal_value_peek_string (param_values + 4),
             data2);
 }
 
+/* VOID:UINT,BOXED (thunar-marshal.list:10) */
+void
+_thunar_marshal_VOID__UINT_BOXED (GClosure     *closure,
+                                  GValue       *return_value G_GNUC_UNUSED,
+                                  guint         n_param_values,
+                                  const GValue *param_values,
+                                  gpointer      invocation_hint G_GNUC_UNUSED,
+                                  gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__UINT_BOXED) (gpointer     data1,
+                                                 guint        arg_1,
+                                                 gpointer     arg_2,
+                                                 gpointer     data2);
+  register GMarshalFunc_VOID__UINT_BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__UINT_BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_uint (param_values + 1),
+            g_marshal_value_peek_boxed (param_values + 2),
+            data2);
+}
+
